Languages
==========

tarakimu.lang

.. automodule:: tarakimu.lang
    :members:
    :undoc-members:
    :show-inheritance:

Swahili
-------

.. automodule:: tarakimu.lang.sw
    :members:
    :undoc-members:
    :show-inheritance:

English
-------

.. automodule:: tarakimu.lang.en
    :members:
    :undoc-members:
    :show-inheritance:
